@@ -13,7 +13,7 @@ __contact__ = 'richard.d.smith@stfc.ac.uk'
 from asset_scanner.core.utils import dict_merge, load_description_files
 
 # 3rd Party Imports
-from ceda_directory_tree import DatasetNode
+from directory_tree import DatasetNode
 
 # Python imports
 import yaml
@@ -139,8 +139,17 @@ class ItemDescriptions:
         Dict values are overridden by more specific files and
         arrays are appended to, with duplicates ignored.
 
+        .. note::
+            For remote filepaths (e.g. https://... or gs://) a ``/``
+            character will be pre-pended. This is to enable the lookup
+            to pass as the root node of the tree is ``/``.
+
         :param filepath: Path for which to retrieve the description
         """
+
+        if not filepath[0] == '/':
+            filepath = f'/{filepath}'
+
         nodes = self.tree.search_all(filepath)
         description_files = [node.description_file for node in nodes]
 
